@@ -3,8 +3,9 @@ from typing import List, Union
 from objectrest.json_handler import *
 
 
-def _create_object(json_data: dict, model: type, sub_keys: List = None, extract_list: bool = False) \
-        -> Union[object, None]:
+def _create_object(
+    json_data: dict, model: type, sub_keys: List = None, extract_list: bool = False
+) -> Union[object, None]:
     """
     Parse JSON data into a Pydantic model
     """
@@ -24,9 +25,16 @@ def _create_object(json_data: dict, model: type, sub_keys: List = None, extract_
         return None
 
 
-def get_object(url: str, model: type, sub_keys: List = None, extract_list: bool = False,
-               session: Session = None, use_proxy: bool = False, log: bool = False, **kwargs) \
-        -> Union[object, None]:
+def get_object(
+    url: str,
+    model: type,
+    sub_keys: List = None,
+    extract_list: bool = False,
+    session: Session = None,
+    use_proxy: bool = False,
+    log: bool = False,
+    **kwargs
+) -> Union[object, None]:
     """
     Parse the JSON data from a GET request into an object
 
@@ -49,13 +57,24 @@ def get_object(url: str, model: type, sub_keys: List = None, extract_list: bool
     :return: an object
     :rtype: object
     """
-    json_data = get_json(url=url, session=session, use_proxy=use_proxy, log=log, **kwargs)
-    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list)
+    json_data = get_json(
+        url=url, session=session, use_proxy=use_proxy, log=log, **kwargs
+    )
+    return _create_object(
+        json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list
+    )
 
 
-def post_object(url: str, model: type, sub_keys: List = None, extract_list: bool = False,
-                session: Session = None, use_proxy: bool = False, log: bool = False, **kwargs) \
-        -> Union[object, None]:
+def post_object(
+    url: str,
+    model: type,
+    sub_keys: List = None,
+    extract_list: bool = False,
+    session: Session = None,
+    use_proxy: bool = False,
+    log: bool = False,
+    **kwargs
+) -> Union[object, None]:
     """
     Parse the JSON data from a POST request into an object
 
@@ -78,13 +97,24 @@ def post_object(url: str, model: type, sub_keys: List = None, extract_list: bool
     :return: an object
     :rtype: object
     """
-    json_data = post_json(url=url, session=session, use_proxy=use_proxy, log=log, **kwargs)
-    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list)
+    json_data = post_json(
+        url=url, session=session, use_proxy=use_proxy, log=log, **kwargs
+    )
+    return _create_object(
+        json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list
+    )
 
 
-def put_object(url: str, model: type, sub_keys: List = None, extract_list: bool = False,
-               session: Session = None, use_proxy: bool = False, log: bool = False, **kwargs) \
-        -> Union[object, None]:
+def put_object(
+    url: str,
+    model: type,
+    sub_keys: List = None,
+    extract_list: bool = False,
+    session: Session = None,
+    use_proxy: bool = False,
+    log: bool = False,
+    **kwargs
+) -> Union[object, None]:
     """
     Parse the JSON data from a PUT request into an object
 
@@ -107,13 +137,24 @@ def put_object(url: str, model: type, sub_keys: List = None, extract_list: bool
     :return: an object
     :rtype: object
     """
-    json_data = put_json(url=url, session=session, use_proxy=use_proxy, log=log, **kwargs)
-    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list)
+    json_data = put_json(
+        url=url, session=session, use_proxy=use_proxy, log=log, **kwargs
+    )
+    return _create_object(
+        json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list
+    )
 
 
-def patch_object(url: str, model: type, sub_keys: List = None, extract_list: bool = False,
-                 session: Session = None, use_proxy: bool = False, log: bool = False, **kwargs) \
-        -> Union[object, None]:
+def patch_object(
+    url: str,
+    model: type,
+    sub_keys: List = None,
+    extract_list: bool = False,
+    session: Session = None,
+    use_proxy: bool = False,
+    log: bool = False,
+    **kwargs
+) -> Union[object, None]:
     """
     Parse the JSON data from a PATCH request into an object
 
@@ -136,13 +177,24 @@ def patch_object(url: str, model: type, sub_keys: List = None, extract_list: boo
     :return: an object
     :rtype: object
     """
-    json_data = patch_json(url=url, session=session, use_proxy=use_proxy, log=log, **kwargs)
-    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list)
+    json_data = patch_json(
+        url=url, session=session, use_proxy=use_proxy, log=log, **kwargs
+    )
+    return _create_object(
+        json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list
+    )
 
 
-def delete_object(url: str, model: type, sub_keys: List = None, extract_list: bool = False,
-                  session: Session = None, use_proxy: bool = False, log: bool = False, **kwargs) \
-        -> Union[object, None]:
+def delete_object(
+    url: str,
+    model: type,
+    sub_keys: List = None,
+    extract_list: bool = False,
+    session: Session = None,
+    use_proxy: bool = False,
+    log: bool = False,
+    **kwargs
+) -> Union[object, None]:
     """
     Parse the JSON data from a DELETE request into an object
 
@@ -165,5 +217,9 @@ def delete_object(url: str, model: type, sub_keys: List = None, extract_list: bo
     :return: an object
     :rtype: object
     """
-    json_data = delete_json(url=url, session=session, use_proxy=use_proxy, log=log, **kwargs)
-    return _create_object(json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list)
+    json_data = delete_json(
+        url=url, session=session, use_proxy=use_proxy, log=log, **kwargs
+    )
+    return _create_object(
+        json_data=json_data, model=model, sub_keys=sub_keys, extract_list=extract_list
+    )
